<?php

	/*
	* Plugin Name: Estimated Delivery Date For Backorders
	* Plugin URI: https://www.pluginhive.com/product/estimated-delivery-date-plugin-woocommerce/
	* Description: Use this Plugin to manage Estimted Delivery Date for your Backorder Products.
	* Author: PluginHive
	* Author URI: https://pluginhive.com/
	* Version: 1.1.5
	* Text Domain: ph_estimated_delivery_backorder_addon
	* Copyright: 2020 PluginHive.
	* WC requires at least: 3.0.0
	* WC tested up to: 5.5.2
	* Estimated Delivery Plugin tested up to 1.9.3
	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	function ph_check_for_required_plugins()
	{

		$ph_addon_required_plugins 	= false;

		$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

		// Multisite case
		if ( is_multisite() ) {
			$active_plugins = array_merge( $active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
		}

		if ( in_array( 'wf-estimated-delivery-for-woocommerce/wf-estimated-delivery.php', $active_plugins ) ) {

			$ph_addon_required_plugins = true;
		}

		return $ph_addon_required_plugins;
	}

	// Auto Deactivate
	add_action( 'admin_init', 'ph_estimated_delivery_backorder_addon_deactivate' );

	if ( ! function_exists( 'ph_estimated_delivery_backorder_addon_deactivate' ) ) {
		function ph_estimated_delivery_backorder_addon_deactivate() {

			$ph_required_plugins 	= ph_check_for_required_plugins();

			if ( !$ph_required_plugins ) {

				deactivate_plugins( plugin_basename( __FILE__ ) );
				wp_safe_redirect( admin_url('plugins.php') );
			}
		}
	}

	function ph_backorder_activation_check(){

		$ph_required_plugins 	= ph_check_for_required_plugins();

		if ( !$ph_required_plugins ) {

			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Estimated Delivery Date For Backorders without activating Estimated Delivery Plugin. Kindly activate <b>Estimated Delivery Plugin</b> and then try again", "ph_estimated_delivery_backorder_addon" ), "", array('back_link' => 1 ));
		}
	}

	register_activation_hook( __FILE__, 'ph_backorder_activation_check' );

	if( !class_exists('Ph_Estimated_Delivery_Backorder_Addon') ) {

		class Ph_Estimated_Delivery_Backorder_Addon {

			public static $stock_status_arr = array( 'onbackorder' );

			public function __construct() {

				$this->id		= 'ph_estimated_delivery_backorder_addon';

				add_filter( 'admin_enqueue_scripts', array( $this, 'ph_estimated_delivery_scripts' ) );

				add_filter( 'woocommerce_settings_tabs_array', array( $this, 'ph_estimated_delivery_backorder_addon_settings_tab'), 50 );
				add_action( 'woocommerce_settings_tabs_'.$this->id, array( $this, 'ph_estimated_delivery_backorder_addon_output') );
				add_action( 'woocommerce_update_options_'.$this->id, array( $this, 'ph_estimated_delivery_backorder_addon_update') );
				add_action( 'woocommerce_admin_field_backorder_rule_matrix', array( $this, 'backorder_rule_matrix' ) );

				add_filter( 'woocommerce_admin_settings_sanitize_option_ph_estimated_delivery_backorder_addon', array( $this, 'delete_empty_data_before_saving'), 10, 3 );

				add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'ph_estimated_delivery_backorder_addon_action_links' ) );

				include_once( 'includes/ph-estimated-delivery-settings-option.php' );

				$settings_obj = new PH_Estimated_Delivery_Settings_Option();

				require_once( 'includes/ph-estimated-delivery-skip-calculation.php' );
				require_once( 'includes/ph-estimated-delivery-add-extra-days.php' );
				require_once( 'includes/ph-estimated-delivery-add-fixed-or-custom-text.php' );

			}

			public function ph_estimated_delivery_scripts() {

				wp_enqueue_script( 'ph-estimated-delivery-script', plugins_url( '/resources/js/ph-common.js', __FILE__ ), array( 'jquery' ) );
			}

			public function ph_get_settings_url() {

				return version_compare(WC()->version, '1.0', '>=') ? "wc-settings" : "woocommerce_settings";
			}

			public function ph_estimated_delivery_backorder_addon_action_links( $links ) {

				$plugin_links = array(

					'<a href="' . admin_url( 'admin.php?page=' . $this->ph_get_settings_url() . '&tab=ph_estimated_delivery_backorder_addon' ) . '">' . __( 'Settings', 'ph_estimated_delivery_backorder_addon' ) . '</a>',
				);

				return array_merge( $plugin_links, $links );
			}

			public function delete_empty_data_before_saving( $value, $option, $raw_value ) {

				if( is_array($value) && isset($value['rule_matrix']) ) {
					foreach( $value['rule_matrix'] as $key => $rule ) {

						if( empty($rule['product']) && empty($rule['shipping_class']) ) {
							unset($value['rule_matrix'][$key]);
						} elseif ( empty($rule['date'][0]) && empty($rule['range'][0]) && empty($rule['number'][0]) ) {
							unset($value['rule_matrix'][$key]);
						}

					}
				}

				return $value;
			}

			public function ph_estimated_delivery_backorder_addon_settings_tab( $settings_tabs ) {

				$settings_tabs[$this->id] = __( 'Backorder Estimated Delivery', 'ph_estimated_delivery_backorder_addon' );

				return $settings_tabs;
			}

			public function ph_estimated_delivery_backorder_addon_output() {

				woocommerce_admin_fields( $this->ph_estimated_delivery_backorder_addon_get_settings() );
			}

			public function ph_estimated_delivery_backorder_addon_update() {

				woocommerce_update_options( $this->ph_estimated_delivery_backorder_addon_get_settings() );
			}

			public function ph_estimated_delivery_backorder_addon_get_settings() {

				$settings = array(
					'backorder_title' => array(
						'title'		=> __( 'Estimated Delivery Date For Backorders', 'ph_estimated_delivery_backorder_addon' ),
						'type'		=> 'title',
						'id'		=> 'backorder_title',
						'value'		=> __( 'Estimated Delivery Date For Backorders', 'ph_estimated_delivery_backorder_addon' ),
					),
					'backorder_status' => array(
						'title'		=> __( 'Show Only For Backorder Products', 'ph_estimated_delivery_backorder_addon' ),
						'type'		=> 'checkbox',
						'default'	=> 'no',
						'desc'		=> __(' Enable<br/><small>Enabling this option will hide estimated delivery for non backorder product.</small>', 'ph_estimated_delivery_backorder_addon' ),
						'id'		=> 'backorder_status'
					),
					'on_all_products' => array(
						'title'		=> __( 'Ignore Product Backorder Status', 'ph_estimated_delivery_backorder_addon' ),
						'type'		=> 'checkbox',
						'default'	=> 'no',
						'desc'		=> __(' Enable<br/><small>Enabling this option will show estimated delivery for all product irrespective of the stock-status for below configured rules.</small>', 'ph_estimated_delivery_backorder_addon' ),
						'id'		=> 'on_all_products'
					),
					'backorder_rule_matrix' => array(
						'title'		=> __( 'Backorder Rules', 'ph_estimated_delivery_backorder_addon' ),
						'type'		=> 'backorder_rule_matrix',
						'value'		=> '',
					),
					'section_end' => array(
						'type'		=> 'sectionend',
						'id'		=> 'ph_estimated_delivery_backorder_addon',
						'value'		=> '',
					)
				);

				return apply_filters( 'wc_settings_ph_estimated_delivery_backorder_addon_settings', $settings );
			}

			public function backorder_rule_matrix() {

				$shipping_class_obj 			= new WC_Shipping;											
				$available_shipping_classes 	= $shipping_class_obj->get_shipping_classes();
				$this->shipping_class_list		= array();

				foreach($available_shipping_classes as $shipping_class) {
					
					$this->shipping_class_list[$shipping_class->slug] = $shipping_class->name;
				}

				ob_start();
				$tool_tip_icon = plugins_url("woocommerce/assets/images/help.png");
				?>
				<style>
					/*Style for tooltip*/
					.ph-tooltip
					{
						position: relative;
						top: 5px;
					}
					.ph-tooltip .ph-tooltiptext
					{
						visibility: hidden;
						width: 150px;
						background-color: #333;
						color: #fff;
						text-align: center;
						border-radius: 3px; 
						padding: .618em 1em;
						font-size: .8em;
						/* Position the tooltip */
						position: absolute; z-index: 1;
					}
					.ph-tooltip:hover .ph-tooltiptext
					{
						visibility: visible;
					}
					/*End of tooltip styling*/

					.ph-search {
						float: left !important;
						width: 100% !important;
					}
					.ph-search input {
						float: left !important;
					}
				</style>

				<table class ="wp-list-table widefat fixed posts">
					<thead>
						<tr>

							<th>
								<?php _e( "Product Name", "ph_estimated_delivery_backorder_addon");
								echo '<span class="ph-tooltip"><img src="'.$tool_tip_icon.'" height="18" width="18" /><span class="ph-tooltiptext">Select the Product</span></span>';?>
							</th>

							<th>
								<?php _e( "Shipping Class", "ph_estimated_delivery_backorder_addon");
								echo '<span class="ph-tooltip"><img src="'.$tool_tip_icon.'" height="18" width="18" /><span class="ph-tooltiptext">Select the Shipping Class</span></span>';?>
							</th>

							<th>
								<?php _e( "Extra Delivery Date Format","ph_estimated_delivery_backorder_addon");
								echo '<span class="ph-tooltip"><img src="'.$tool_tip_icon.'" height="18" width="18" /><span class="ph-tooltiptext">Choose how you want to display Estimated Delivery Date for Backordered Products</span></span>'; ?>
							</th>

							<th>
								<?php _e( "Estimated Delivery Date Value", "ph_estimated_delivery_backorder_addon");
								echo '<span class="ph-tooltip"><img src="'.$tool_tip_icon.'" height="18" width="18" /><span class="ph-tooltiptext">Enter additional number of days, the exact date of delivery or any custom text you want to display.</span></span>';?>
							</th>

						</tr>
					</thead>

					<?php

					$rule_count 	= 0;
					$settings 		= get_option('ph_estimated_delivery_backorder_addon');

					if( ! empty($settings['rule_matrix']) ) {

						foreach( $settings['rule_matrix'] as $rule ) {

							?>
							<tbody>
								<tr>

									<td>
										<div class="ph-search">
											<select class="wc-product-search" multiple="multiple" style="width: 100%;" name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][product][]" data-placeholder="<?php esc_attr_e( 'Search for a product&hellip;', 'ph_estimated_delivery_backorder_addon' ); ?>" data-action="woocommerce_json_search_products_and_variations">
												<?php

												$product_ids = isset($rule['product']) && is_array($rule['product']) ? $rule['product'] : array();

												if( !empty($product_ids) ) {

													foreach ( $product_ids as $product_id ) {

														$product = wc_get_product( $product_id );

														if ( is_object( $product ) ) {
															echo '<option value="' . esc_attr( $product_id ) . '"' . selected( true, true, false ) . '>' . wp_kses_post( $product->get_formatted_name() ) . '</option>';
														}
													}
												}
												?>
											</select>
										</div>
									</td>

									<td>
										<select name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][shipping_class][]" multiple="multiple" style="width: 100%;" class="wc-enhanced-select">
											<?php

											foreach( $this->shipping_class_list as $key => $value ) {
												if( isset($rule['shipping_class']) && is_array($rule['shipping_class']) && in_array( $key, $rule['shipping_class'] ) ) {
													echo "<option value='".$key."' selected>".$value."</option>";
												}
												else {
													echo "<option value='".$key."'>".$value."</option>";
												}
											}
											?>
										</select>
									</td>

									<td>
										<select name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][format][]" class="wc-enhanced-select format" style="width: 100%;">
											<?php 
											$date_selected = '';
											if( is_array($rule['format']) && in_array( 'fixed_date', $rule['format'] ) ) 
											{
												$date_selected = "fixed_date";
											}
											elseif( is_array($rule['format']) && in_array( 'fixed_range', $rule['format'] ) )
											{
												$date_selected = "fixed_range";
											}
											if( $date_selected == "fixed_date" ){
												?>
												<option value ='fixed_date' selected="selected">Fixed Date</option>
												<option value ='fixed_range'>Custom Text</option>
												<option value ='num_of_days'>No. of Additional Days</option>
												<?php
											}elseif( $date_selected == "fixed_range" ){
												?>
												<option value ='fixed_date'>Fixed Date</option>
												<option value ='fixed_range' selected="selected">Custom Text</option>
												<option value ='num_of_days'>No. of Additional Days</option>
												<?php
											}else{
												?>
												<option value ='fixed_date'>Fixed Date</option>
												<option value ='fixed_range'>Custom Text</option>
												<option value ='num_of_days' selected="selected">No. of Additional Days</option>
												<?php
											}
											?>
										</select>
									</td>
									<td class="value_type">
										<input class="num" type="number" style="width: 100%; border-radius: 5px; text-align: left; <?php echo !in_array( 'num_of_days', $rule['format'] )?'display:none':''?> " name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][number][]" placeholder="Number Of Additional Days" value="<?php echo $rule['number'][0];?>">

										<input class="range" type="text" style="width: 100%; border-radius: 5px; text-align: left; <?php echo !in_array( 'fixed_range', $rule['format'] )?'display:none':''?> " name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][range][]"
										placeholder="Ex: 10-12 Days / 4 to 5 Weeks" value="<?php echo $rule['range'][0];?>">

										<input class="fixed" type="date" style="width: 100%; border-radius: 5px; text-align: left; <?php echo !in_array( 'fixed_date', $rule['format'] )?'display:none':''?> " name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][date][]" value="<?php echo $rule['date'][0];?>">
									</td>
								</tr>
								<?php
								$rule_count++;
							}
						}
						?>
						<tr>

							<td>
								<div class="ph-search">
									<select class="wc-product-search" multiple="multiple" style="width: 100%;" name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][product][]" data-placeholder="<?php esc_attr_e( 'Search for a product&hellip;', 'ph_estimated_delivery_backorder_addon' ); ?>" data-action="woocommerce_json_search_products_and_variations"></select>
								</div>
							</td>

							<td>
								<select name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][shipping_class][]" multiple="multiple" style="width: 100%;" class="wc-enhanced-select">
									<?php
									foreach( $this->shipping_class_list as $key => $value ) {
										echo "<option value='".$key."'>".$value."</option>";
									}
									?>
								</select>
							</td>

							<td>
								<select class="wc-enhanced-select format" style="width: 100%;" name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][format][]">
									<option value ='fixed_date' selected>Fixed Date</option>
									<option value ='fixed_range'>Custom Text</option>
									<option value ='num_of_days'>No. of Additional Days</option>
								</select>
							</td>
							<td>
								<input class="fixed" type="date" style="width: 100%; border-radius: 5px; text-align: left; " name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][date][]">

								<input class="range" type="text" style="width: 100%; border-radius: 5px; text-align: left; display: none; " name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][range][]" placeholder="Ex: 10-12 Days / 4 to 5 Weeks">

								<input class="num" type="number" style="width: 100%; border-radius: 5px; text-align: left; display: none; " name="ph_estimated_delivery_backorder_addon[rule_matrix][<?php echo $rule_count; ?>][number][]" placeholder="Number Of Additional Days">


							</td>
						</tr>
					</tbody>

				</table>

				<?php
				ob_end_flush();

			}

		}

		new Ph_Estimated_Delivery_Backorder_Addon();
	}